@startuml

component AgentPipeline {
    DefaultAgentPipeline -down-* AgentPipelineOverview
    class DefaultAgentPipeline {
        + overview : AgentPipelineOverview
    }


    ' PipelineContainer *-up- AgentPipeline

    class AgentPipelineOverview {
        + pipeline : AgentPipeline
        + pipelineComponents : Array<PipelineComponent>
        + components : Array<PipelineComponent>
    }
}

component PipelineComponent {
    AgentPipelineOverview "1" -left- "1..*" DefaultPipelineComponent : contains

    ' PipelineComponent -- PipelineContainer
    class DefaultPipelineComponent {
        + pipelineComponentId : UUID
        + type : String
        + container : PipelineContainer
        + agent : Agent
    }

}




component Agent {
    DefaultPipelineComponent "1" -right-> "1" DefaultAgent : uses
    IAgent "1" -right- "1" AgentConfig
    interface IAgent as "Agent" {
        + agentId : UUID
        + name : String
        + description : String
        + update() : JSON
    }
    ' DefaultAgent .up.|> Agent

    DefaultAgent .up.|> IAgent
    class DefaultAgent {
        + agentId : UUID
        + name : String
        + description : String
        + config : AgentConfig
    }


    ' AgentConfig -- Agent
    interface AgentConfig {
        + agentConfig : JSON
        + aiModelSession : AIModelSession
    }


}




class SessionConfigAdapter as "Session Config Adapter"
SessionConfigAdapter .up.|> SessionConfig



' AIModelSession ..up.|> Session
interface Session {
    + sessionId : UUID
    + config : SessionConfig
}
Session "1" -left-> "1" SessionConfig


' SessionConfig -- Session
interface SessionConfig {
    + config : JSON
}
' AIModelSessionConfig .up.|> SessionConfig
' GeminiSessionConfig .up.|> SessionConfig
' GrokSessionConfig ..up.|> SessionConfig
' SessionConfigAdapter .up.|> SessionConfig














AIModel .up.|> LLM
AIModel "1" -down- "1" AIModelSession
class AIModel {
    - apiKey : String

    + modelId : UUID
    + type : String
    + url : URL
    + session : AIModelSession
}
' Gemini --up-|> AIModel
' Grok ----up-|> AIModel

component AIModelSession {
    AgentConfig "1" --> "1" DefaultAIModelSession
    DefaultAIModelSession ..up.|> Session
    DefaultAIModelSession "1" -right- "1" AIModelSessionConfig
    ' AIModelSession -- AIModel
    class DefaultAIModelSession {
        + model : AIModel
        + config : AIModelSessionConfig
    }
    ' GeminiSession .up.|> AIModelSession
    ' GrokSession ..up.|> AIModelSession



    AIModelSessionConfig .up.|> SessionConfig
    ' AIModelSessionConfig -- AIModelSession
    AIModelSessionConfig "1" -- "1" RequestConfig
    AIModelSessionConfig "1" -- "1" ResponseSchema
    class AIModelSessionConfig {
        + session : AIModelSession
        + request : RequestConfig
        + schema : ResponseSchema
    }
    ' GeminiSessionConfig .up.|> AIModelSessionConfig
    ' GrokSessionConfig ..up.|> AIModelSessionConfig

    interface RequestConfig {
        + config : JSON
    }

    ' interface ResponseConfig {
    '     + response : JSON
    ' }

    interface ResponseSchema {
        + schema : JSON
    }
}

class ESMModule

' Gemini .up.|> LLM


component Gemini {
    DefaultGemini -------up-|> AIModel
    DefaultGemini "1" --down- "1" GeminiClient
    class DefaultGemini {
        - geminiClient : GeminiClient
        + session : GeminiSession
    }


    GeminiClient ---up-|> ESMModule
    class GeminiClient {
        + config : GeminiSessionConfig
    }
}



component GeminiSession {
    DefaultGemini "1" -- "1" DefaultGeminiSession
    DefaultGeminiSession -up-|> DefaultAIModelSession
    ' GeminiSession -- Gemini
    DefaultGeminiSession -right-> GeminiSessionConfig
    GeminiSessionConfig -up-|> AIModelSessionConfig

    class DefaultGeminiSession {
        + model : Gemini
        + config : GeminiSessionConfig
    }



    ' GeminiSessionConfig -- GeminiSession
    class GeminiSessionConfig {
        + session : GeminiSession
    }
}



component Grok {

    DefaultGrok --------up-|> AIModel
    DefaultGrok "1" --down- "1" GrokClient
    class DefaultGrok  {
        - grokClient : GrokClient
        + session : GrokSession
    }


    GrokClient ---up-|> ESMModule
    class GrokClient {
        + config : GrokSessionConfig
    }

}






component GrokSession {
    DefaultGrok "1" -- "1" DefaultGrokSession
    DefaultGrokSession --right-> GrokSessionConfig
    DefaultGrokSession --up-|> DefaultAIModelSession
    ' GrokSession -left- Grok

    class DefaultGrokSession {
        + model : Grok
        + config : GrokSessionConfig
    }

    GrokSessionConfig --up-|> AIModelSessionConfig
    class GrokSessionConfig {
        + session : GrokSession
    }
}

' AIModel .up.|> LLM
' Gemini .up.|> LLM
' Grok ...up.|> LLM
interface LLM {
    + llmId : UUID
    + name : String
    + description : String
    + process(request : RequestConfig, config : AIModelConfig) : ResponseConfig
}


@enduml